#! /usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const build_1 = require("./build");
const start_watch_1 = require("./start-watch");
const run_angular_cli_1 = require("./run-angular-cli");
const configuration_1 = require("./shared/configuration");
const verify_sandboxes_1 = require("./verify-sandboxes");
const find_port_1 = require("./shared/find-port");
(() => __awaiter(this, void 0, void 0, function* () {
    yield run();
}))();
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        const rawArgs = process.argv.slice(2);
        const config = new configuration_1.Configuration(rawArgs);
        let sandboxPort, playgroundConfig;
        let configFile = path.resolve(config.flags.config.value);
        try {
            playgroundConfig = require(configFile.replace(/.json$/, ''));
        }
        catch (e) {
            process.stdout.write(`[angular-playground]: \x1b[31mFailed to load config file ${configFile}\x1b[0m\n`);
            process.exit(1);
        }
        // Parity between command line arguments and configuration file
        config.applyConfigurationFile(playgroundConfig);
        const sandboxesPath = yield build_1.build(playgroundConfig.sourceRoot);
        if (config.flags.checkErrors.value) {
            // get port dynamically
            const port = yield find_port_1.findFirstFreePort('127.0.0.1', 7000, 9000);
            sandboxPort = port;
            config.flags.angularCli.port.value = port;
        }
        if (!config.flags.noWatch.value) {
            start_watch_1.startWatch(config.flags.sourceRoot.value, () => build_1.build(config.flags.sourceRoot.value));
        }
        if (!config.flags.noServe.value && playgroundConfig.angularCli) {
            run_angular_cli_1.runAngularCli(config, playgroundConfig.angularCli);
        }
        if (config.flags.checkErrors.value) {
            verify_sandboxes_1.verifySandboxes(config, sandboxesPath, sandboxPort);
        }
    });
}
